You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by js...@apache.org on 2006/08/08 23:47:11 UTC

svn commit: r429833 [4/5] - in /incubator/tuscany/cpp/sca: ./ doc/ projects/tuscany_sca/ projects/tuscany_sca/tuscany_sca/ projects/tuscany_sca/tuscany_sca_test/ projects/tuscany_sca/tuscany_sca_test/testSCASystem/composites/ projects/tuscany_sca/tusca...

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/Calculator/Calculator.vcproj
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/Calculator/Calculator.vcproj?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/Calculator/Calculator.vcproj (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/Calculator/Calculator.vcproj Tue Aug  8 14:47:01 2006
@@ -132,59 +132,59 @@
 			Name="Source Files"
 			Filter="cpp;c;cxx;rc;def;r;odl;idl;hpj;bat">
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\Calculator.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\Calculator.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorDivideService_Proxy.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorDivideService_Proxy.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorDivideService_Proxy.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorDivideService_Proxy.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Proxy.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Proxy.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Proxy.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Proxy.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Wrapper.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Wrapper.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\CalculatorImpl_CalculatorService_Wrapper.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\CalculatorImpl_CalculatorService_Wrapper.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideService.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideService.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Proxy.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Proxy.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Proxy.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Proxy.h">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Wrapper.cpp">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Wrapper.cpp">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\DivideServiceImpl_DivideService_Wrapper.h">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\DivideServiceImpl_DivideService_Wrapper.h">
 			</File>
 		</Filter>
 		<Filter
 			Name="Resource Files"
 			Filter="ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe">
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\Calculator.wsdl">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\Calculator.wsdl">
 				<FileConfiguration
 					Name="Debug|Win32">
 					<Tool
@@ -197,16 +197,16 @@
 				</FileConfiguration>
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\Tuscany-model.config">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\Tuscany-model.config">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\sca.module">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\sca.composite">
 			</File>
 			<File
 				RelativePath="..\..\..\..\..\Calculator\CalculatorSubsystem\sca.subsystem">
 			</File>
 			<File
-				RelativePath="..\..\..\..\..\Calculator\CalculatorModule\services.xml">
+				RelativePath="..\..\..\..\..\Calculator\CalculatorComposite\services.xml">
 			</File>
 		</Filter>
 		<Filter

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/WSClient/BuildInstructions.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/WSClient/BuildInstructions.txt?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/WSClient/BuildInstructions.txt (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/WSClient/BuildInstructions.txt Tue Aug  8 14:47:01 2006
@@ -20,13 +20,13 @@
 TUSCANY_SDOCPP:
 The directory where the sdo runtime is deployed - probably something ending in sdo/deploy.
 
-TUSCANY_SCACPP_DEFAULT_MODULE:
-This is the default module to be loaded by SCA. It consists of <subsystem>/<component>.
+TUSCANY_SCACPP_DEFAULT_COMPOSITE:
+This is the default composite to be loaded by SCA. It consists of <subsystem>/<component>.
 In the case of this sample - its set programatically by the client - thats easier when
 using visual studio.
 
 TUSCANY_SCACPP_SYSTEM_ROOT
-This is the point from which SCA will start looking for modules to load. Again this is
+This is the point from which SCA will start looking for composites to load. Again this is
 set programmatically by the sample.
 
 AXIS2C_HOME:
@@ -41,9 +41,9 @@
 
 If required, go to the Calculator sample main directory, and
 type:
-"scagen -dir CalculatorModule -output CalculatorModule" 
+"scagen -dir CalculatorComposite -output CalculatorComposite" 
 
-The generated code is put into the CalculatorModule subdirectory.
+The generated code is put into the CalculatorComposite subdirectory.
 
 Building the Client project
 ===========================

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/deploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/deploy.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/deploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/deploy.cmd Tue Aug  8 14:47:01 2006
@@ -32,18 +32,18 @@
 set destinationPath=%2
 )
 
-if not exist %destinationPath%\modules mkdir %destinationPath%\modules 
-if not exist %destinationPath%\modules\CalculatorModule mkdir %destinationPath%\modules\CalculatorModule
+if not exist %destinationPath%\composites mkdir %destinationPath%\composites 
+if not exist %destinationPath%\composites\CalculatorComposite mkdir %destinationPath%\composites\CalculatorComposite
 
-copy %sourcePath%\CalculatorModule\*.componentType %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\sca.module %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\CalculatorImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideService.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideServiceImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Tuscany-model.config %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.wsdl %destinationPath%\modules\CalculatorModule
-copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\modules\CalculatorModule
+copy %sourcePath%\CalculatorComposite\*.componentType %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\sca.composite %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\CalculatorImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideService.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideServiceImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Tuscany-model.config %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.wsdl %destinationPath%\composites\CalculatorComposite
+copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\composites\CalculatorComposite
 
 if not exist %destinationPath%\bin mkdir %destinationPath%\bin
 copy %currentPath%\Client\%buildMode%\Client.exe %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/wsdeploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/wsdeploy.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/wsdeploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/ides/devstudio7/projects/Calculator/wsdeploy.cmd Tue Aug  8 14:47:01 2006
@@ -33,18 +33,18 @@
 )
 
 
-if not exist %destinationPath%\modules mkdir %destinationPath%\modules 
-if not exist %destinationPath%\modules\CalculatorModule mkdir %destinationPath%\modules\CalculatorModule
+if not exist %destinationPath%\composites mkdir %destinationPath%\composites 
+if not exist %destinationPath%\composites\CalculatorComposite mkdir %destinationPath%\composites\CalculatorComposite
 
-copy %sourcePath%\CalculatorModule\*.componentType %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\sca.module %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\CalculatorImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideService.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\DivideServiceImpl.h %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Tuscany-model.config %destinationPath%\modules\CalculatorModule
-copy %sourcePath%\CalculatorModule\Calculator.wsdl %destinationPath%\modules\CalculatorModule
-copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\modules\CalculatorModule
+copy %sourcePath%\CalculatorComposite\*.componentType %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\sca.composite %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\CalculatorImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideService.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\DivideServiceImpl.h %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Tuscany-model.config %destinationPath%\composites\CalculatorComposite
+copy %sourcePath%\CalculatorComposite\Calculator.wsdl %destinationPath%\composites\CalculatorComposite
+copy %currentPath%\Calculator\%buildMode%\Calculator.dll %destinationPath%\composites\CalculatorComposite
 
 if not exist %destinationPath%\bin mkdir       %destinationPath%\bin
 copy %currentPath%\WSClient\%buildMode%\WSClient.exe %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestClient/WSEntryPointTestClient.c
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestClient/WSEntryPointTestClient.c?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/WSEntryPointTestModule.vcproj (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/WSEntryPointTestModule.vcproj Tue Aug  8 14:47:01 2006
@@ -2,7 +2,7 @@
 <VisualStudioProject
 	ProjectType="Visual C++"
 	Version="7.10"
-	Name="WSEntryPointTestModule"
+	Name="WSEntryPointTestComposite"
 	ProjectGUID="{19C4CE76-4E08-4C22-8198-010B837C565A}"
 	Keyword="Win32Proj">
 	<Platforms>
@@ -20,7 +20,7 @@
 				Name="VCCLCompilerTool"
 				Optimization="0"
 				AdditionalIncludeDirectories="$(TUSCANY_SCACPP)/include,$(TUSCANY_SDOCPP)/include,$(AXIS2C_HOME)/include"
-				PreprocessorDefinitions="WIN32;_DEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTMODULE_EXPORTS"
+				PreprocessorDefinitions="WIN32;_DEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTCOMPOSITE_EXPORTS"
 				MinimalRebuild="TRUE"
 				BasicRuntimeChecks="3"
 				RuntimeLibrary="1"
@@ -33,13 +33,13 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalDependencies="tuscany_sca.lib tuscany_sdo.lib tuscany_sdo_axiom.lib axis2_parser.lib axis2_util.lib axiom.lib"
-				OutputFile="$(OutDir)/WSEntryPointTestModule.dll"
+				OutputFile="$(OutDir)/WSEntryPointTestComposite.dll"
 				LinkIncremental="2"
 				AdditionalLibraryDirectories="$(TUSCANY_SCACPP)/lib,$(TUSCANY_SDOCPP)/lib,$(AXIS2C_HOME)/lib"
 				GenerateDebugInformation="TRUE"
-				ProgramDatabaseFile="$(OutDir)/WSEntryPointTestModule.pdb"
+				ProgramDatabaseFile="$(OutDir)/WSEntryPointTestComposite.pdb"
 				SubSystem="2"
-				ImportLibrary="$(OutDir)/WSEntryPointTestModule.lib"
+				ImportLibrary="$(OutDir)/WSEntryPointTestComposite.lib"
 				TargetMachine="1"/>
 			<Tool
 				Name="VCMIDLTool"/>
@@ -70,7 +70,7 @@
 			CharacterSet="2">
 			<Tool
 				Name="VCCLCompilerTool"
-				PreprocessorDefinitions="WIN32;NDEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTMODULE_EXPORTS"
+				PreprocessorDefinitions="WIN32;NDEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTCOMPOSITE_EXPORTS"
 				RuntimeLibrary="0"
 				UsePrecompiledHeader="0"
 				WarningLevel="3"
@@ -80,13 +80,13 @@
 				Name="VCCustomBuildTool"/>
 			<Tool
 				Name="VCLinkerTool"
-				OutputFile="$(OutDir)/WSEntryPointTestModule.dll"
+				OutputFile="$(OutDir)/WSEntryPointTestComposite.dll"
 				LinkIncremental="1"
 				GenerateDebugInformation="TRUE"
 				SubSystem="2"
 				OptimizeReferences="2"
 				EnableCOMDATFolding="2"
-				ImportLibrary="$(OutDir)/WSEntryPointTestModule.lib"
+				ImportLibrary="$(OutDir)/WSEntryPointTestComposite.lib"
 				TargetMachine="1"/>
 			<Tool
 				Name="VCMIDLTool"/>
@@ -149,7 +149,7 @@
 			Filter="rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx"
 			UniqueIdentifier="{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}">
 			<File
-				RelativePath=".\sca.module">
+				RelativePath=".\sca.composite">
 			</File>
 			<File
 				RelativePath="..\WSEntryPointTestSubsystem\sca.subsystem">

Added: incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="ASCII"?>
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	name="WSEntryPointTestComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSEntryPointTestEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="WSEntryPointTest.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.WSEntryPointTest.org/WSEntryPointTest/#wsdl.endpoint(WSEntryPointTest/WSEntryPointTestSOAP)"></binding.ws>
+		<reference>WSEntryPointTestServiceComponent</reference>
+	</entryPoint>
+
+
+	<component name="WSEntryPointTestServiceComponent">
+		<implementation.cpp dll="WSEntryPointTestComposite.dll" header="WSEntryPointTestImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references> </references>
+	</component>
+</composite>

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
 
 <subsystem xmlns="http://www.osoa.org/xmlns/sca/0.9" name="WSEntryPointTestSubsystem">
 	
-        <moduleComponent name="WSEntryPointTestService" module="WSEntryPointTestModule" />
+        <compositeComponent name="WSEntryPointTestService" composite="WSEntryPointTestComposite" />
 
 </subsystem>
 	

Added: incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/composites/WSEntryPointTestComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/composites/WSEntryPointTestComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/composites/WSEntryPointTestComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/composites/WSEntryPointTestComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="ASCII"?>
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	name="WSEntryPointTestComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSEntryPointTestEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="WSEntryPointTest.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.WSEntryPointTest.org/WSEntryPointTest/#wsdl.endpoint(WSEntryPointTest/WSEntryPointTestSOAP)"></binding.ws>
+		<reference>WSEntryPointTestServiceComponent</reference>
+	</entryPoint>
+
+
+	<component name="WSEntryPointTestServiceComponent">
+		<implementation.cpp dll="WSEntryPointTestComposite.dll" header="WSEntryPointTestImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references> </references>
+	</component>
+</composite>

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/subsystems/WSEntryPointTestSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/subsystems/WSEntryPointTestSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/subsystems/WSEntryPointTestSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/runtime/subsystems/WSEntryPointTestSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
 
 <subsystem xmlns="http://www.osoa.org/xmlns/sca/0.9" name="WSEntryPointTestSubsystem">
 	
-        <moduleComponent name="WSEntryPointTestService" module="WSEntryPointTestModule" />
+        <compositeComponent name="WSEntryPointTestService" composite="WSEntryPointTestComposite" />
 
 </subsystem>
 	

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCClient/WSEntryPointTestRPCClient.c
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCClient/WSEntryPointTestRPCClient.c?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/WSEntryPointTestRPCModule.vcproj (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/WSEntryPointTestRPCModule.vcproj Tue Aug  8 14:47:01 2006
@@ -2,7 +2,7 @@
 <VisualStudioProject
 	ProjectType="Visual C++"
 	Version="7.10"
-	Name="WSEntryPointTestRPCModule"
+	Name="WSEntryPointTestRPCComposite"
 	ProjectGUID="{6F98DD05-6B3D-4C06-9E1C-AF3256DCA7EA}"
 	Keyword="Win32Proj">
 	<Platforms>
@@ -20,7 +20,7 @@
 				Name="VCCLCompilerTool"
 				Optimization="0"
 				AdditionalIncludeDirectories="$(TUSCANY_SCACPP)/include,$(TUSCANY_SDOCPP)/include"
-				PreprocessorDefinitions="WIN32;_DEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTRPCMODULE_EXPORTS"
+				PreprocessorDefinitions="WIN32;_DEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTRPCCOMPOSITE_EXPORTS"
 				MinimalRebuild="TRUE"
 				BasicRuntimeChecks="3"
 				RuntimeLibrary="1"
@@ -33,13 +33,13 @@
 			<Tool
 				Name="VCLinkerTool"
 				AdditionalDependencies="tuscany_sca.lib tuscany_sdo.lib"
-				OutputFile="$(OutDir)/WSEntryPointTestRPCModule.dll"
+				OutputFile="$(OutDir)/WSEntryPointTestRPCComposite.dll"
 				LinkIncremental="2"
 				AdditionalLibraryDirectories="$(TUSCANY_SCACPP)/lib,$(TUSCANY_SDOCPP)/lib"
 				GenerateDebugInformation="TRUE"
-				ProgramDatabaseFile="$(OutDir)/WSEntryPointTestRPCModule.pdb"
+				ProgramDatabaseFile="$(OutDir)/WSEntryPointTestRPCComposite.pdb"
 				SubSystem="2"
-				ImportLibrary="$(OutDir)/WSEntryPointTestRPCModule.lib"
+				ImportLibrary="$(OutDir)/WSEntryPointTestRPCComposite.lib"
 				TargetMachine="1"/>
 			<Tool
 				Name="VCMIDLTool"/>
@@ -70,7 +70,7 @@
 			CharacterSet="2">
 			<Tool
 				Name="VCCLCompilerTool"
-				PreprocessorDefinitions="WIN32;NDEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTRPCMODULE_EXPORTS"
+				PreprocessorDefinitions="WIN32;NDEBUG;_WINDOWS;_USRDLL;WSENTRYPOINTTESTRPCCOMPOSITE_EXPORTS"
 				RuntimeLibrary="0"
 				UsePrecompiledHeader="0"
 				WarningLevel="3"
@@ -80,13 +80,13 @@
 				Name="VCCustomBuildTool"/>
 			<Tool
 				Name="VCLinkerTool"
-				OutputFile="$(OutDir)/WSEntryPointTestRPCModule.dll"
+				OutputFile="$(OutDir)/WSEntryPointTestRPCComposite.dll"
 				LinkIncremental="1"
 				GenerateDebugInformation="TRUE"
 				SubSystem="2"
 				OptimizeReferences="2"
 				EnableCOMDATFolding="2"
-				ImportLibrary="$(OutDir)/WSEntryPointTestRPCModule.lib"
+				ImportLibrary="$(OutDir)/WSEntryPointTestRPCComposite.lib"
 				TargetMachine="1"/>
 			<Tool
 				Name="VCMIDLTool"/>
@@ -149,7 +149,7 @@
 			Filter="rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx"
 			UniqueIdentifier="{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}">
 			<File
-				RelativePath=".\sca.module">
+				RelativePath=".\sca.composite">
 			</File>
 			<File
 				RelativePath=".\services.xml">

Added: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="ASCII"?>
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	name="WSEntryPointTestRPCComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSEntryPointTestRPCEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="WSEntryPointTestRPC.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.WSEntryPointTest.org/WSEntryPointTestRPC/#wsdl.endpoint(WSEntryPointTestRPC/WSEntryPointTestRPCSOAP)"></binding.ws>
+		<reference>WSEntryPointTestRPCServiceComponent</reference>
+	</entryPoint>
+
+
+	<component name="WSEntryPointTestRPCServiceComponent">
+		<implementation.cpp dll="WSEntryPointTestRPCComposite.dll" header="WSEntryPointTestRPCImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references> </references>
+	</component>
+</composite>

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
 
 <subsystem xmlns="http://www.osoa.org/xmlns/sca/0.9" name="WSEntryPointTestRPCSubsystem">
 	
-        <moduleComponent name="WSEntryPointTestRPCService" module="WSEntryPointTestRPCModule" />
+        <compositeComponent name="WSEntryPointTestRPCService" composite="WSEntryPointTestRPCComposite" />
 
 </subsystem>
 	

Added: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/composites/WSEntryPointTestRPCComposite/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/composites/WSEntryPointTestRPCComposite/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/composites/WSEntryPointTestRPCComposite/sca.composite (added)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/composites/WSEntryPointTestRPCComposite/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="ASCII"?>
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+	name="WSEntryPointTestRPCComposite">
+
+	<!-- Expose as a web service -->
+	<entryPoint name="WSEntryPointTestRPCEntrypoint" multiplicity="1..1">
+		<interface.wsdl interface="WSEntryPointTestRPC.wsdl" callbackInterface=""></interface.wsdl>
+		<binding.ws port="http://www.WSEntryPointTest.org/WSEntryPointTestRPC/#wsdl.endpoint(WSEntryPointTestRPC/WSEntryPointTestRPCSOAP)"></binding.ws>
+		<reference>WSEntryPointTestRPCServiceComponent</reference>
+	</entryPoint>
+
+
+	<component name="WSEntryPointTestRPCServiceComponent">
+		<implementation.cpp dll="WSEntryPointTestRPCComposite.dll" header="WSEntryPointTestRPCImpl.h"></implementation.cpp>
+                <properties> </properties>
+		<references> </references>
+	</component>
+</composite>

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/subsystems/WSEntryPointTestRPCSubsystem/sca.subsystem
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/subsystems/WSEntryPointTestRPCSubsystem/sca.subsystem?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/subsystems/WSEntryPointTestRPCSubsystem/sca.subsystem (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/runtime/subsystems/WSEntryPointTestRPCSubsystem/sca.subsystem Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
 
 <subsystem xmlns="http://www.osoa.org/xmlns/sca/0.9" name="WSEntryPointTestRPCSubsystem">
 	
-        <moduleComponent name="WSEntryPointTestRPCService" module="WSEntryPointTestRPCModule" />
+        <compositeComponent name="WSEntryPointTestRPCService" composite="WSEntryPointTestRPCComposite" />
 
 </subsystem>
 	

Propchange: incubator/tuscany/cpp/sca/tools/scagen/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Tue Aug  8 14:47:01 2006
@@ -18,8 +18,15 @@
 .deps
 *.dat
 .libs
-deploy
 tmp
 bld
-scagen_build
+.project
+.cdtproject
+.settings
+.classpath
+*_Proxy.cpp
+*_Proxy.h
+*_Wrapper.cpp
+*_Wrapper.h
 docs
+scagen_build

Modified: incubator/tuscany/cpp/sca/tools/scagen/build.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/build.xml?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/build.xml (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/build.xml Tue Aug  8 14:47:01 2006
@@ -31,7 +31,7 @@
     </target>
 
     <target name="test" depends="init,jars,test.jar">
-        <java classname="org.apache.tuscany.sca.cpp.tools.junit.TestAllModulesTest">
+        <java classname="org.apache.tuscany.sca.cpp.tools.junit.TestAllCompositesTest">
             <classpath>
                 <pathelement location="${build.result.folder}/test.jar" />
                 <pathelement location="${junit.jar.folder}/junit.jar" />

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/CalculatorTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/CalculatorTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/CalculatorTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/CalculatorTest.java Tue Aug  8 14:47:01 2006
@@ -23,7 +23,7 @@
  */
 public class CalculatorTest extends TuscanyTestCase {
 
-    public void testCalculatorModuleAndComponent() {
-        testModule("CalculatorModuleAndComponent", check_results);
+    public void testCalculatorCompositeAndComponent() {
+        testComposite("CalculatorCompositeAndComponent", check_results);
     }
 }

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/EnvHandlerTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/EnvHandlerTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go.cmd (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go.cmd Tue Aug  8 14:47:01 2006
@@ -1,2 +1,2 @@
 rm -rf out
-java -jar scagen.jar -dir c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule -output c:\hydra\out
+java -jar scagen.jar -dir c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite -output c:\hydra\out

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_dir_option.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_dir_option.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_dir_option.cmd (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_dir_option.cmd Tue Aug  8 14:47:01 2006
@@ -1 +1 @@
-java -jar scagen.jar -dirX c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule -output c:\hydra\out
+java -jar scagen.jar -dirX c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite -output c:\hydra\out

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_output_dir.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_output_dir.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_output_dir.cmd (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go_no_output_dir.cmd Tue Aug  8 14:47:01 2006
@@ -1 +1 @@
-java -jar scagen.jar -dir c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule -output r:\hydra\out
+java -jar scagen.jar -dir c:\workspaces\wid60-no-core\Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite -output r:\hydra\out

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/CalculatorImpl.componentType
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/CalculatorImpl.componentType?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/CalculatorImpl.componentType (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/CalculatorImpl.componentType Tue Aug  8 14:47:01 2006
@@ -20,6 +20,6 @@
 
 <componentType xmlns="http://www.osoa.org/xmlns/sca/0.9">
     <service name="CalculatorService">
-        <interface.cpp header="Calculator.h"/> <!-- Header is relative to the module root -->
+        <interface.cpp header="Calculator.h"/> <!-- Header is relative to the composite root -->
     </service>
 </componentType>

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorModuleAndComponent/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,28 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
+-->    
+ 
+
+<composite   xmlns="http://www.osoa.org/xmlns/sca/0.9"   name="Calculator">
+
+   <component name="Calculator">
+      <implementation.cpp dll="debug/Calculator.dll" header="CalculatorImpl.h"/>
+   </component>
+
+</composite>

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,31 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+
+<composite   xmlns="http://www.osoa.org/xmlns/sca/0.9"   name="Calculator">
+
+   <component name="CalculatorForward">
+      <implementation.cpp header="subFolder/CalculatorForwardImpl.h"/>
+   </component>
+   
+    <component name="CalculatorBack">
+      <implementation.cpp header="subFolder\CalculatorBackImpl.h"/>
+   </component>
+
+</composite>

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorBackImpl.componentType
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorBackImpl.componentType?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorBackImpl.componentType (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorBackImpl.componentType Tue Aug  8 14:47:01 2006
@@ -20,6 +20,6 @@
 
 <componentType xmlns="http://www.osoa.org/xmlns/sca/0.9">
     <service name="CalculatorService">
-        <interface.cpp header="otherSubFolder\CalculatorBack.h"/> <!-- Header is relative to the module root -->
+        <interface.cpp header="otherSubFolder\CalculatorBack.h"/> <!-- Header is relative to the composite root -->
     </service>
 </componentType>

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorForwardImpl.componentType
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorForwardImpl.componentType?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorForwardImpl.componentType (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CalculatorSlashDirectionTest/subFolder/CalculatorForwardImpl.componentType Tue Aug  8 14:47:01 2006
@@ -20,6 +20,6 @@
 
 <componentType xmlns="http://www.osoa.org/xmlns/sca/0.9">
     <service name="CalculatorService">
-        <interface.cpp header="otherSubFolder/CalculatorForward.h"/> <!-- Header is relative to the module root -->
+        <interface.cpp header="otherSubFolder/CalculatorForward.h"/> <!-- Header is relative to the composite root -->
     </service>
 </componentType>

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplMultiParamDiffTypesTest/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplMultiParamDiffTypesTest/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplMultiParamDiffTypesTest/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplMultiParamDiffTypesTest/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -18,7 +18,7 @@
  */        
  -->
 
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
    xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
    xmlns:mvs="http://www.myvalue.org/MyValueService/"
    name="CustomerInfoComponent">
@@ -35,5 +35,5 @@
       </references>
    </component>
 
-</moduleFragment>
+</compositeFragment>
    

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplSingleParamDiffTypesTest/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplSingleParamDiffTypesTest/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplSingleParamDiffTypesTest/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/CustomerInfoImplSingleParamDiffTypesTest/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -18,7 +18,7 @@
  */        
  -->
 
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
    xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
    xmlns:mvs="http://www.myvalue.org/MyValueService/"
    name="CustomerInfoComponent">
@@ -35,5 +35,5 @@
       </references>
    </component>
 
-</moduleFragment>
+</compositeFragment>
    

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceCompositeIntfClassWithNamespaceButNotInClassAttr/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceCompositeIntfClassWithNamespaceButNotInClassAttr/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceCompositeIntfClassWithNamespaceButNotInClassAttr/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceCompositeIntfClassWithNamespaceButNotInClassAttr/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,48 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   
\ No newline at end of file

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
  *  limitations under the License.
  */        
  -->
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
    xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
    xmlns:mvs="http://www.myvalue.org/MyValueService/"
    name="CustomerInfoComponent">
@@ -34,5 +34,5 @@
       </references>
    </component>
 
-</moduleFragment>
+</compositeFragment>
    

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModule/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+   
+   <!--
+   <component name="Calculator">
+      <implementation.cpp dll="debug/Calculator.dll" header="CalculatorImpl.h"/>
+   </component>
+   -->
+
+   <externalService name="StockQuoteService">
+      <interface.cpp header="StockQuoteService.h"/>
+      <binding.ws port="http://swanandmokashi.com#wsdl.endpoint(StockQuotes/StockQuotesSoap)"/>
+   </externalService>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   
\ No newline at end of file

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/CustomerInfo.fragment
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/CustomerInfo.fragment?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/CustomerInfo.fragment (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/CustomerInfo.fragment Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
  *  limitations under the License.
  */        
  -->
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
    xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
    xmlns:mvs="http://www.myvalue.org/MyValueService/"
    name="CustomerInfoComponent">
@@ -34,5 +34,5 @@
       </references>
    </component>
 
-</moduleFragment>
+</compositeFragment>
    

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespace/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+   
+   <!--
+   <component name="Calculator">
+      <implementation.cpp dll="debug/Calculator.dll" header="CalculatorImpl.h"/>
+   </component>
+   -->
+
+   <externalService name="StockQuoteService">
+      <interface.cpp header="StockQuoteService.h"/>
+      <binding.ws port="http://swanandmokashi.com#wsdl.endpoint(StockQuotes/StockQuotesSoap)"/>
+   </externalService>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   
\ No newline at end of file

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,96 @@
+<?xml version="1.0" encoding="ASCII"?>
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   

Added: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleIntfClassWithNamespace/sca.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleIntfClassWithNamespace/sca.composite?rev=429833&view=auto
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleIntfClassWithNamespace/sca.composite (added)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleIntfClassWithNamespace/sca.composite Tue Aug  8 14:47:01 2006
@@ -0,0 +1,48 @@
+<?xml version="1.0" encoding="ASCII"?>
+<!--
+/*
+ *
+ *  Copyright 2005 The Apache Software Foundation or its licensors, as applicable.
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */        
+ -->
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+   xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
+   xmlns:mvs="http://www.myvalue.org/MyValueService/"
+   name="MyValueServiceComposite">
+
+   <!-- Expose as a web service -->
+   <entryPoint name="MyValueServiceExport" multiplicity="1..1">
+      <interface.wsdl interface="" callbackInterface=""></interface.wsdl>
+      <binding.ws port="mvs:MyValueServiceSOAP"></binding.ws>
+      <reference>MyValueServiceComponent</reference>
+   </entryPoint>
+
+   <component name="MyValueServiceComponent">
+      <implementation.cpp dll="MyValue" header="MyValueImpl.hpp"></implementation.cpp>
+      <properties>
+      </properties>
+      <references>
+         <customerInfo>CustomerInfoComponent</customerInfo>
+         <stockQuote>StockQuoteService</stockQuote>
+      </references>
+   </component>
+
+   <!--wire>
+      <source.uri>MyValueServiceComponent/customerInfo</source.uri>
+      <target.uri>CustomerInfoComponent</target.uri>
+   </wire-->
+
+</composite>
+   
\ No newline at end of file

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/CustomerInfo.fragmentX
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/CustomerInfo.fragmentX?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/CustomerInfo.fragmentX (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/CustomerInfo.fragmentX Tue Aug  8 14:47:01 2006
@@ -17,7 +17,7 @@
  *  limitations under the License.
  */        
  -->
-<moduleFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<compositeFragment xmlns="http://www.osoa.org/xmlns/sca/0.9" 
 	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
 	xmlns:mvs="http://www.myvalue.org/MyValueService/"
 	name="CustomerInfoComponent">
@@ -34,5 +34,5 @@
 		</references>
 	</component>
 
-</moduleFragment>
+</compositeFragment>
 	

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/sca.moduleX
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/sca.moduleX?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/sca.moduleX (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/testinput/composites/MyValueServiceModuleMissingScaModule/sca.moduleX Tue Aug  8 14:47:01 2006
@@ -18,10 +18,10 @@
  */        
  -->
 
-<module xmlns="http://www.osoa.org/xmlns/sca/0.9" 
+<composite xmlns="http://www.osoa.org/xmlns/sca/0.9" 
 	xmlns:v="http://www.osoa.org/xmlns/sca/values/0.9" 
 	xmlns:mvs="http://www.myvalue.org/MyValueService/"
-	name="MyValueServiceModule">
+	name="MyValueServiceComposite">
 
 	<!-- Expose as a web service -->
 	<entryPoint name="MyValueServiceExport" multiplicity="1..1">
@@ -56,5 +56,5 @@
 		<target.uri>CustomerInfoComponent</target.uri>
 	</wire-->
 
-</module>
+</composite>
 	



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestClient/WSEntryPointTestClient.c (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestClient/WSEntryPointTestClient.c Tue Aug  8 14:47:01 2006
@@ -135,8 +135,8 @@
     /* Set service client options */
     AXIS2_SVC_CLIENT_SET_OPTIONS(svc_client, env, options);    
 
-    /* Engage addressing module */
-    AXIS2_SVC_CLIENT_ENGAGE_MODULE(svc_client, env, AXIS2_MODULE_ADDRESSING);
+    /* Engage addressing composite */
+    AXIS2_SVC_CLIENT_ENGAGE_COMPOSITE(svc_client, env, AXIS2_COMPOSITE_ADDRESSING);
     
     /* Send request */
     ret_node = AXIS2_SVC_CLIENT_SEND_RECEIVE(svc_client, env, payload);

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/WSEntryPointTestModule.vcproj
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTest/WSEntryPointTestComposite/WSEntryPointTestModule.vcproj?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCClient/WSEntryPointTestRPCClient.c (original)
+++ incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCClient/WSEntryPointTestRPCClient.c Tue Aug  8 14:47:01 2006
@@ -63,8 +63,8 @@
      * using the axis2.xml file.
      * In this sample client_home points to the Axis2/C default deploy folder. The client_home can 
      * be different from this folder on your system. For example, you may have a different folder 
-     * (say, my_client_folder) with its own axis2.xml file. my_client_folder/modules will have the 
-     * modules that the client uses
+     * (say, my_client_folder) with its own axis2.xml file. my_client_folder/composites will have the 
+     * composites that the client uses
      */
     client_home = AXIS2_GETENV("AXIS2C_HOME");
     if (!client_home)
@@ -86,8 +86,8 @@
     /* Set service client options */
     AXIS2_SVC_CLIENT_SET_OPTIONS(svc_client, &env, options);    
     
-    /* Engage addressing module */
-    AXIS2_SVC_CLIENT_ENGAGE_MODULE(svc_client, &env, AXIS2_MODULE_ADDRESSING);
+    /* Engage addressing composite */
+    AXIS2_SVC_CLIENT_ENGAGE_COMPOSITE(svc_client, &env, AXIS2_COMPOSITE_ADDRESSING);
     
     /* Build the SOAP request message payload using OM API.*/
     payload = build_om_payload_for_WSEntryPointTestRPC_svc(env);

Modified: incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/WSEntryPointTestRPCModule.vcproj
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/test/WSEntryPointTestRPC/WSEntryPointTestRPCComposite/WSEntryPointTestRPCModule.vcproj?rev=429833&r1=429532&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/EnvHandlerTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/EnvHandlerTest.java Tue Aug  8 14:47:01 2006
@@ -19,7 +19,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
 public class EnvHandlerTest extends TuscanyTestCase {
@@ -34,11 +34,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModule", check_results);
+        testComposite("MyValueServiceComposite", check_results);
     }
 
 }
@@ -19,7 +19,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -34,11 +34,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceButNotInClassAttrTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceButNotInClassAttrTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceButNotInClassAttrTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceButNotInClassAttrTest.java Tue Aug  8 14:47:01 2006
@@ -20,7 +20,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr SCA module as
  * input data.
  */
 public class ImplClassWithNameSpaceButNotInClassAttrTest extends TuscanyTestCase {
@@ -35,11 +35,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr", check_results);
+        testComposite("MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr", check_results);
     }
 
 }
@@ -63,7 +63,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr SCA module as
  * input data.
  */
 public class ImplClassWithNameSpaceButNotInClassAttrTest extends TuscanyTestCase {
@@ -78,11 +78,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr", check_results);
+        testComposite("MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr", check_results);
     }
 
 }
@@ -20,7 +20,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr SCA composite as
  * input data.
  */
@@ -35,11 +35,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr
      * proxy and wrapper generation.
      */
@@ -63,7 +63,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr SCA composite as
  * input data.
  */
@@ -78,11 +78,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModuleImplClassWithNamespaceButNotInClassAttr
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceCompositeImplClassWithNamespaceButNotInClassAttr
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/ImplClassWithNameSpaceTest.java Tue Aug  8 14:47:01 2006
@@ -19,7 +19,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
 public class ImplClassWithNameSpaceTest extends TuscanyTestCase {
@@ -34,11 +34,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleImplClassWithNamespace", check_results);
+        testComposite("MyValueServiceCompositeImplClassWithNamespace", check_results);
     }
 
 }
@@ -19,7 +19,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -34,11 +34,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceButNotInClassAttrTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceButNotInClassAttrTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceButNotInClassAttrTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceButNotInClassAttrTest.java Tue Aug  8 14:47:01 2006
@@ -19,7 +19,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
 public class IntfClassWithNameSpaceButNotInClassAttrTest extends TuscanyTestCase {
@@ -34,11 +34,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleIntfClassWithNamespaceButNotInClassAttr", check_results);
+        testComposite("MyValueServiceCompositeIntfClassWithNamespaceButNotInClassAttr", check_results);
     }
 
 }
@@ -19,7 +19,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -34,11 +34,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/IntfClassWithNameSpaceTest.java Tue Aug  8 14:47:01 2006
@@ -19,7 +19,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
 public class IntfClassWithNameSpaceTest extends TuscanyTestCase {
@@ -34,11 +34,11 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleIntfClassWithNamespace", check_results);
+        testComposite("MyValueServiceCompositeIntfClassWithNamespace", check_results);
     }
 
 }
@@ -19,7 +19,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -34,11 +34,11 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/MissingModuleAndFragmentTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/MissingModuleAndFragmentTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/MissingModuleAndFragmentTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/MissingModuleAndFragmentTest.java Tue Aug  8 14:47:01 2006
@@ -19,26 +19,26 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
-public class MissingModuleAndFragmentTest extends TuscanyTestCase {
+public class MissingCompositeAndFragmentTest extends TuscanyTestCase {
 
     /**
      * Constructor for CustomerInfoTestOLD.
      * 
      * @param arg0
      */
-    public MissingModuleAndFragmentTest(String arg0) {
+    public MissingCompositeAndFragmentTest(String arg0) {
         super(arg0);
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
-        testModule("MyValueServiceModuleMissingScaModule",check_results);
+        testComposite("MyValueServiceCompositeMissingScaComposite",check_results);
     }
 
 }
@@ -19,26 +19,26 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -19,26 +19,26 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/SimplePublicPrivateProtectedTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/SimplePublicPrivateProtectedTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/SimplePublicPrivateProtectedTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/SimplePublicPrivateProtectedTest.java Tue Aug  8 14:47:01 2006
@@ -19,7 +19,7 @@
 /**
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
  * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
  * input data.
  */
 public class SimplePublicPrivateProtectedTest extends TuscanyTestCase {
@@ -34,12 +34,12 @@
     }
 
     /**
      * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
      * proxy and wrapper generation.
      */
     public void testEnvHandler() {
 
-        testModule("SimplePublicPrivateProtectedTest", check_results);
+        testComposite("SimplePublicPrivateProtectedTest", check_results);
     }
 
 }
@@ -19,7 +19,7 @@
  * This is a "run this first" testcase that just tests some simple operations of
  * the scagen tools it uses the
- * Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule SCA module as
+ * Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite SCA composite as
  * input data.
  */
@@ -34,12 +34,12 @@
 
     /**
-     * Test the Hydra.sca.core\test\testSCASystem\modules\MyValueServiceModule
+     * Test the Hydra.sca.core\test\testSCASystem\composites\MyValueServiceComposite
      * proxy and wrapper generation.
      */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestAllModulesTest.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestAllModulesTest.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestAllModulesTest.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestAllModulesTest.java Tue Aug  8 14:47:01 2006
@@ -21,18 +21,18 @@
 import org.apache.tuscany.sca.cpp.tools.junit.TuscanyTestCase;
 
 /**
  * This test case will test all the modules placed in the "modules" directory
  * against the results in their repectice "expected_results" folders.
  */
-public class TestAllModulesTest extends TuscanyTestCase {
+public class TestAllCompositesTest extends TuscanyTestCase {
 
-    String testsDir = TuscanyTestCase.junit_modules;
+    String testsDir = TuscanyTestCase.junit_composites;
 
     Set excludes = new HashSet();
 
-    public TestAllModulesTest(String arg0) {
+    public TestAllCompositesTest(String arg0) {
         super(arg0);
-        excludes.add("MyValueServiceModuleMissingScaModule");
+        excludes.add("MyValueServiceCompositeMissingScaComposite");
         excludes.add("CVS");
         excludes.add(".svn");
     }
@@ -40,33 +40,33 @@
     
     /* main exists to allow running from the java ant task */
     public static void main(String[] args) {
-        TestAllModulesTest test = new TestAllModulesTest("");
-        test.testAllModulesRegression();
+        TestAllCompositesTest test = new TestAllCompositesTest("");
+        test.testAllCompositesRegression();
     }
     
-    public void testAllModulesRegression() {
+    public void testAllCompositesRegression() {
         File dir = new File(testsDir);
 
         if (dir.isDirectory()) {
-            System.out.println("Testing all modules under "
+            System.out.println("Testing all composites under "
                     + dir.getAbsolutePath());
-            String[] test_modules = dir.list();
+            String[] test_composites = dir.list();
 
-            for (int i = 0; i < test_modules.length; i++) {
-                File test_module = new File(testsDir, test_modules[i]);
+            for (int i = 0; i < test_composites.length; i++) {
+                File test_composite = new File(testsDir, test_composites[i]);
 
-                String module_name = null;
-                if (test_module.isDirectory()) {
-                    module_name = test_module.getName();
-                    if (!excludes.contains(module_name.intern())) {
-                        testModule(module_name, check_results);
-                        System.out.println("Test of module \"" + module_name
+                String composite_name = null;
+                if (test_composite.isDirectory()) {
+                    composite_name = test_composite.getName();
+                    if (!excludes.contains(composite_name.intern())) {
+                        testComposite(composite_name, check_results);
+                        System.out.println("Test of composite \"" + composite_name
                                 + "\" passed.");
                         continue;
                     } else {
                         System.out
-                                .println("Ignoring excluded module subdirectory \""
-                                        + module_name + "\"");
+                                .println("Ignoring excluded composite subdirectory \""
+                                        + composite_name + "\"");
                     }
                 }
             }
@@ -74,10 +74,10 @@
         } else {
 
             fail("Test directory is not a directory! \r The variable org.apache.tuscany.sca.cpp.tools.junit.TuscanyTestCase.root sets the location of the junit input data,\r it is currently set as "
-                    + TuscanyTestCase.root + "\rand we expect to find a testinput\\modules directory under there.");
+                    + TuscanyTestCase.root + "\rand we expect to find a testinput\\composites directory under there.");
         }
 
-        System.out.println("testAllModules test passed.");
+        System.out.println("testAllComposites test passed.");
     }
 
 }
@@ -21,18 +21,18 @@
 
 /**
- * This test case will test all the modules placed in the "modules" directory
+ * This test case will test all the composites placed in the "composites" directory
  * against the results in their repectice "expected_results" folders.
  */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestDeployAssistTool.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestDeployAssistTool.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestDeployAssistTool.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TestDeployAssistTool.java Tue Aug  8 14:47:01 2006
@@ -19,18 +19,18 @@
 import java.util.Set;
 
 /**
  * This test case will test all the modules placed in the "modules" directory
  * against the results in their repectice "expected_results" folders.
  */
 public class TestDeployAssistTool extends TuscanyTestCase {
 
-    String testsDir = TuscanyTestCase.junit_modules;
+    String testsDir = TuscanyTestCase.junit_composites;
 
     Set excludes = new HashSet();
 
     public TestDeployAssistTool(String arg0) {
         super(arg0);
-        excludes.add("MyValueServiceModuleMissingScaModule");
+        excludes.add("MyValueServiceCompositeMissingScaComposite");
         excludes.add("CVS");
     }
 
@@ -46,19 +46,19 @@
 
     public void testDeployTool() {
         //Utils.setReportArtefacts(true);
-        TestAllModulesTest t = new TestAllModulesTest("");
+        TestAllCompositesTest t = new TestAllCompositesTest("");
         File dir = new File(testsDir);
 
         if (dir.isDirectory()) {
-            String[] test_modules = dir.list();
+            String[] test_composites = dir.list();
 
-            for (int i = 0; i < test_modules.length; i++) {
-                File test_module = new File(testsDir, test_modules[i]);
-                String module_name = null;
-                if (test_module.isDirectory()) {
-                    module_name = test_module.getName();
-                    if (!excludes.contains(module_name.intern())) {
-                        t.testModuleDeploy(module_name, create_results, "c:\\colin", "cp");
+            for (int i = 0; i < test_composites.length; i++) {
+                File test_composite = new File(testsDir, test_composites[i]);
+                String composite_name = null;
+                if (test_composite.isDirectory()) {
+                    composite_name = test_composite.getName();
+                    if (!excludes.contains(composite_name.intern())) {
+                        t.testCompositeDeploy(composite_name, create_results, "c:\\colin", "cp");
                     }
                 }
                 System.out.println("");
@@ -68,19 +68,19 @@
     
     public void testDeployToolNullParms() {
         //Utils.setReportArtefacts(true);
-        TestAllModulesTest t = new TestAllModulesTest("");
+        TestAllCompositesTest t = new TestAllCompositesTest("");
         File dir = new File(testsDir);
 
         if (dir.isDirectory()) {
-            String[] test_modules = dir.list();
+            String[] test_composites = dir.list();
 
-            for (int i = 0; i < test_modules.length; i++) {
-                File test_module = new File(testsDir, test_modules[i]);
-                String module_name = null;
-                if (test_module.isDirectory()) {
-                    module_name = test_module.getName();
-                    if (!excludes.contains(module_name.intern())) {
-                        t.testModuleDeploy(module_name, create_results, null, null);
+            for (int i = 0; i < test_composites.length; i++) {
+                File test_composite = new File(testsDir, test_composites[i]);
+                String composite_name = null;
+                if (test_composite.isDirectory()) {
+                    composite_name = test_composite.getName();
+                    if (!excludes.contains(composite_name.intern())) {
+                        t.testCompositeDeploy(composite_name, create_results, null, null);
                     }
                 }
                 System.out.println("");
@@ -19,18 +19,18 @@
 
 /**
- * This test case will test all the modules placed in the "modules" directory
+ * This test case will test all the composites placed in the "composites" directory
  * against the results in their repectice "expected_results" folders.
  */

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TuscanyTestCase.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TuscanyTestCase.java?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================
--- incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TuscanyTestCase.java (original)
+++ incubator/tuscany/cpp/sca/tools/scagen/junit/org/apache/tuscany/sca/cpp/tools/junit/TuscanyTestCase.java Tue Aug  8 14:47:01 2006
@@ -35,7 +35,7 @@
 
     public static String root = "d:\\tuscany\\cpp\\sca\\tools\\scagen\\junit\\";
 
-    public static String junit_modules = root + "testinput\\modules\\";
+    public static String junit_composites = root + "testinput\\composites\\";
 
     public static String junit_output = root + "testoutput\\";
 
@@ -47,7 +47,7 @@
 
     /**
      * Check the resulting files with the contents of the expected_results
      * folder in the testModule method
      */
     public final static boolean check_results = true;
 
@@ -180,10 +180,10 @@
 
     }
 
-    public void testModule(String module, boolean check) {
+    public void testComposite(String composite, boolean check) {
 
         Options.reset();
-        setTestcase(module);
+        setTestcase(composite);
         clearDirButNotExpectedOutputSubDir(output);
 
         String[] commandLine = new String[] { "-dir", input, "-output", output };
@@ -198,11 +198,11 @@
         }
     }
 
-    public void testModuleDeploy(String module, boolean check,
+    public void testCompositeDeploy(String composite, boolean check,
             String deployDir, String command) {
 
         Options.reset();
-        setTestcase(module);
+        setTestcase(composite);
         clearDirButNotExpectedOutputSubDir(output);
 
         String[] commandLine;
@@ -323,7 +323,7 @@
      */
     void setTestcase(String testcase) {
         this.testcase = testcase;
-        input = TuscanyTestCase.junit_modules + testcase;
+        input = TuscanyTestCase.junit_composites + testcase;
         output = TuscanyTestCase.junit_output + testcase;
     }
 
@@ -47,7 +47,7 @@
     /**
      * Check the resulting files with the contents of the expected_results
-     * folder in the testModule method
+     * folder in the testComposite method
      */
     public final static boolean check_results = true;

Modified: incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/tools/scagen/junit/scripts_for_standalone_testing/go.cmd?rev=429833&r1=429832&r2=429833&view=diff
==============================================================================